==> swiftlang_5.8.1.orig.tar.xz: swiftlang-5.8.1/swift-docc/Sources/docc/DocCDocumentation.docc/Reference Syntax/API Reference Syntax/Metadata.md <==
# ``docc/Metadata``

Use metadata directives to instruct DocC how to build certain documentation files.

@Metadata {
    @DocumentationExtension(mergeBehavior: override)
}

## Overview

Use the `Metadata` directive with other directives to configure how certain documentation files build. Place the directive after the documentation page's title. Use it with the ``DocumentationExtension`` directive to indicate whether content in a documentation extension file amends or replaces in-source documentation.

```
# ``SlothCreator/Sloth``

@Metadata {
    @DocumentationExtension(mergeBehavior: append)
}
````

Use the `Metadata` directive with the ``TechnologyRoot`` directive to configure a documentation page that's not associated with a particular framework, so that page appears as a top-level page.

Use the `Metadata` directive with the ``DisplayName`` directive to configure a symbol's documentation page to use a custom display name.

```
# ``SlothCreator``

@Metadata {
    @DisplayName("Sloth Creator")
}
````

### Contained Elements

A metadata element must contain one of the following items:

- term ``DocumentationExtension``: Defines whether the content in a documentation extension file amends or replaces in-source documentation. **(optional)**
- term ``TechnologyRoot``: Configures a documentation page that's not associated with a particular framework to appear as a top-level page. **(optional)**
- term ``DisplayName``: Configures a symbol's documentation page to use a custom display name. **(optional)**

## Topics

### Extending or Overriding Source Documentation

- ``DocumentationExtension``

### Creating a Top-Level Technology Page

- ``TechnologyRoot``

### Customizing the Presentation of a Page

- ``DisplayName``
- ``PageImage``
- ``CallToAction``

<!-- Copyright (c) 2021-2022 Apple Inc and the Swift Project authors. All Rights Reserved. -->

==> swiftlang_5.9.2.orig.tar.xz: swiftlang-5.9.2/swift-docc/Sources/docc/DocCDocumentation.docc/Reference Syntax/API Reference Syntax/Metadata.md <==
# ``docc/Metadata``

Use metadata directives to instruct DocC how to build certain documentation files.

@Metadata {
    @DocumentationExtension(mergeBehavior: override)
}

## Overview

Use the `Metadata` directive with other directives to configure how certain documentation files build. Place the directive after the documentation page's title. Use it with the ``DocumentationExtension`` directive to indicate whether content in a documentation extension file amends or replaces in-source documentation.

```
# ``SlothCreator/Sloth``

@Metadata {
    @DocumentationExtension(mergeBehavior: append)
}
````

Use the `Metadata` directive with the ``TechnologyRoot`` directive to configure a documentation page that's not associated with a particular framework, so that page appears as a top-level page.

Use the `Metadata` directive with the ``DisplayName`` directive to configure a symbol's documentation page to use a custom display name.

```
# ``SlothCreator``

@Metadata {
    @DisplayName("Sloth Creator")
}
```

Use the `Metadata` directive with the ``TitleHeading`` directive to configure the text of a page's title heading.

```
# ``SlothCreator``

@Metadata {
    @TitleHeading("Release Notes")
}
```

## Topics

### Extending or Overriding Source Documentation

- ``DocumentationExtension``

### Creating a Top-Level Technology Page

- ``TechnologyRoot``

### Customizing the Presentation of a Page

- ``DisplayName``
- ``PageImage``
- ``PageKind``
- ``PageColor``
- ``CallToAction``
- ``TitleHeading``

### Customizing the Languages of an Article

- ``SupportedLanguage``

### Customizing the Availability Information of a Page

- ``Available``

<!-- Copyright (c) 2021-2023 Apple Inc and the Swift Project authors. All Rights Reserved. -->
